Changelog
---------

0.7.1 (2019-07-10)
~~~~~~~~~~~~~~~~~~~~~

- Adds print button to daycare calculator.
  [href]

- Fixes max income notice showing the wrong amount.
  [href]

- Adds iFrame support to the daycare calculator.
  [href]

0.7.0 (2019-06-28)
~~~~~~~~~~~~~~~~~~~~~

- Adds a daycare calculator.
  [href]

0.6.4 (2019-06-14)
~~~~~~~~~~~~~~~~~~~~~

- Fixes imported missions not being hidden in some cases.
  [href]

- Fixes import matching not working in some cases.
  [href]

0.6.3 (2019-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Adds year parameter to mission report overview.
  [href]

0.6.2 (2019-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Fixes date/time not being rendered in the right timezone.
  [href]

- Fixes picture icon position.
  [href]

0.6.1 (2019-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Adds the ability to update existing vehicles with vehicle import.
  [href]

0.6.0 (2019-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Adds import/export commands for mission vehicles.
  [href]

0.5.3 (2019-06-05)
~~~~~~~~~~~~~~~~~~~~~

- Adjusts the Zivilschutz link.
  [href]

0.5.2 (2019-06-03)
~~~~~~~~~~~~~~~~~~~~~

- Adds link to Zivilschutz in mission reports.
  [href]

- Includes hidden missions in mission reports.
  [href]

- Shows a camera icon on mission-reports with pictures.
  [href]

0.5.1 (2019-05-14)
~~~~~~~~~~~~~~~~~~~~~

- Adds roadwork to iFrame paths.
  [href]

0.5.0 (2019-05-06)
~~~~~~~~~~~~~~~~~~~~~

- Adds mission-reports.
  [href]

0.4.4 (2019-04-05)
~~~~~~~~~~~~~~~~~~~~~

- Fixes section filter not working as expected.
  [href]

0.4.3 (2019-04-03)
~~~~~~~~~~~~~~~~~~~~~

- Fixes GIS link target=_blank not working in iFrame.
  [href]

0.4.2 (2019-04-03)
~~~~~~~~~~~~~~~~~~~~~

- Excludes roadwork sections in the past.
  [href]

- Sorts roadwork by title.
  [href]

- Uses _blank for GIS links.
  [href]

0.4.1 (2019-04-01)
~~~~~~~~~~~~~~~~~~~~~

- Adds GIS information to roadworks directory.
  [href]

0.4.0 (2019-03-28)
~~~~~~~~~~~~~~~~~~~~~

- Adds a roadworks directory.
  [href]

0.3.5 (2019-02-28)
~~~~~~~~~~~~~~~~~~~~~

- Fixes external links not targeting "_top".
  [href]

0.3.4 (2019-02-22)
~~~~~~~~~~~~~~~~~~~~~

- Disables test on Travis.
  [href]

0.3.3 (2019-01-30)
~~~~~~~~~~~~~~~~~~~~~

- Adds compatibility with latest onegov.core release.
  [msom]

0.3.2 (2018-12-03)
~~~~~~~~~~~~~~~~~~~~~

- Moves geo code to onegov.gis.
  [href]

0.3.1 (2018-09-18)
~~~~~~~~~~~~~~~~~~~~~

0.3.0 (2018-09-18)
~~~~~~~~~~~~~~~~~~~~~

0.2.14 (2018-09-18)
~~~~~~~~~~~~~~~~~~~~~

0.2.13 (2018-09-18)
~~~~~~~~~~~~~~~~~~~~~

- Switches map mprojection to ESPG:2056.
  [href]

0.2.12 (2018-07-31)
~~~~~~~~~~~~~~~~~~~~~

- Sets the target of exernal links to "_top".
  [href]

- Applies the custom museum layout to all directories.
  [href]

0.2.11 (2018-06-22)
~~~~~~~~~~~~~~~~~~~~~

- Fixes conflict error.
  [href]

0.2.10 (2018-06-22)
~~~~~~~~~~~~~~~~~~~~~

- Always enables the search widget for directories.
  [href]

0.2.9 (2018-06-15)
~~~~~~~~~~~~~~~~~~~~~

- Fixes overzealous bullet point replacements.
  [href]

0.2.8 (2018-06-14)
~~~~~~~~~~~~~~~~~~~~~

- Small design changes.
  [href]

0.2.7 (2018-06-13)
~~~~~~~~~~~~~~~~~~~~~

- Adjusts directory panel styles.
  [href]

- Resets the whole directory if the reset search button is clicked.
  [href]

- Sorts search results in order of importance.
  [href]

- Shows a clear button in the search box.
  [href]

- Limits hover link javascript to .with-thumbnails.
  [href]

0.2.6 (2018-06-12)
~~~~~~~~~~~~~~~~~~~~~

- Floats images in directories to the right.
  [href]

0.2.5 (2018-06-12)
~~~~~~~~~~~~~~~~~~~~~

- Decreases fuzziness of search results.
  [href]

- Customizes the display of directory entries with thumbnails.
  [href]

0.2.4 (2018-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Ensures separation of Winterthur maps from org.
  [href]

0.2.3 (2018-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Fixes non-https url for Winterthur map.
  [href]

0.2.2 (2018-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Switches global map to the Winterthur custom one.
  [href]

0.2.1 (2018-06-05)
~~~~~~~~~~~~~~~~~~~~~

- Adds a back-link to the directory entry views inside iframes.
  [href]

- Shows a bullet instead of a checkmark in the directory choices.
  [href]

0.2.0 (2018-05-23)
~~~~~~~~~~~~~~~~~~~~~

- Adjusts the style to be closer to the styleguide.
  [href]

0.1.8 (2018-04-30)
~~~~~~~~~~~~~~~~~~~~~

- Adds compatibility with latest onegov.core release.
  [href]

0.1.7 (2018-04-26)
~~~~~~~~~~~~~~~~~~~~~

- Fixes external links not working on IE 11.
  [href]

0.1.6 (2018-03-28)
~~~~~~~~~~~~~~~~~~~~~

- Scrolls to top whenever we load the iframe.
  [href]

0.1.5 (2018-03-23)
~~~~~~~~~~~~~~~~~~~~~

- Fixes streetnames getting wrapped.
  [href]

0.1.4 (2018-03-20)
~~~~~~~~~~~~~~~~~~~~~

- Adjusts framed style.
  [href]

- Discards completely irrevant search results.
  [href]

- Adds support for streets without addresses.
  [href]

0.1.3 (2018-03-08)
~~~~~~~~~~~~~~~~~~~~~

- Fixes iframe height being calculated incorrectly.
  [href]

0.1.2 (2018-03-01)
~~~~~~~~~~~~~~~~~~~~~

- Applies Winterthur's CD to the framed version.
  [href]

0.1.1 (2018-02-06)
~~~~~~~~~~~~~~~~~~~~~

- Adds a frame-ancestors whitelist.
  [href]

0.1.0 (2018-01-31)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [href]
